@@ -379,9 +379,21 @@ Learner = R6Class("Learner",
     deep_clone = function(name, value) {
       switch(name,
         .param_set = value$clone(deep = TRUE),
+        fallback = if (is.null(value)) NULL else value$clone(deep = TRUE),
         state = { value$log = copy(value$log); value },
         value
       )
     }
   )
 )
+
+
+#' @export
+rd_info.Learner = function(obj) {
+  c("",
+    sprintf("* Task type: %s", rd_format_string(obj$task_type)),
+    sprintf("* Predict Types: %s", rd_format_string(obj$predict_types)),
+    sprintf("* Feature Types: %s", rd_format_string(obj$feature_types)),
+    sprintf("* Required Packages: %s", rd_format_packages(obj$packages))
+  )
+}
