@@ -1,8 +1,5 @@
 #' @title Abstract Prediction Object
 #'
-#' @usage NULL
-#' @format [R6::R6Class] object.
-#'
 #' @description
 #' This is the abstract base class for task objects like [PredictionClassif] or [PredictionRegr].
 #'
@@ -13,38 +10,9 @@
 #' 4. Additional predictions based on the class and `predict_type`.
 #'    E.g., the class probabilities for classification or the estimated standard error for regression.
 #'
-#' @section Construction:
-#' This object is constructed via a derived classes, e.g. [PredictionClassif] or [PredictionRegr].
+#' Note that this object is usually constructed via a derived classes, e.g. [PredictionClassif] or [PredictionRegr].
 #'
-#' @section Fields:
-#' * `row_ids` :: (`integer()` | `character()`)\cr
-#'   Vector of row ids for which predictions are stored.
-#'
-#' * `truth` :: `any`\cr
-#'   True (observed) outcome.
-#'
-#' * `task_type` :: `character(1)`\cr
-#'    Stores the type of the [Task].
-#'
-#' * `task_properties` :: `character()`\cr
-#'    Stores properties of the [Task].
-#'
-#' * `predict_types` :: `character()`\cr
-#'   Vector of predict types this object stores.
-#'
-#' * `missing` :: `logical()`\cr
-#'   Returns `row_ids` for which the predictions are missing or incomplete.
-#'
-#' @section Methods:
-#' * `score(measures = NULL, task = NULL, learner = NULL)`\cr
-#'   (list of [Measure], [Task], [Learner]) -> [Prediction]\cr
-#'   Calculates the performance for all provided measures
-#'   [Task] and [Learner] may be `NULL` for most measures, but some measures need to extract information
-#'   from these objects.
-#'
-#' * `help()`\cr
-#'   () -> `NULL`\cr
-#'   Opens the help page for this object.
+#' @template param_measures
 #'
 #' @section S3 Methods:
 #' * `as.data.table(rr)`\cr
@@ -61,19 +29,34 @@
 #' @family Prediction
 Prediction = R6Class("Prediction",
   public = list(
+    #' @field data (named `list()`)\cr
+    #' Internal data structure.
     data = list(),
+
+    #' @field task_type (`character(1)`)\cr
+    #' Required type of the [Task].
     task_type = NULL,
+
+    #' @field task_properties (`character()`)\cr
+    #' Required properties of the [Task].
     task_properties = NULL,
+
+    #' @field predict_types (`character()`)\cr
+    #' Set of predict types this object stores.
     predict_types = character(),
 
-    help = function() {
-      open_help("mlr3::Prediction")
-    },
+    #' @template field_man
+    man = "mlr3::Prediction",
 
+    #' @description
+    #' Helper for print outputs.
     format = function() {
       sprintf("<%s>", class(self)[1L])
     },
 
+    #' @description
+    #' Printer.
+    #' @param ... (ignored).
     print = function(...) {
       if (!nrow(self$data$tab)) {
         catf("%s for 0 observations", format(self))
@@ -84,6 +67,24 @@ Prediction = R6Class("Prediction",
       }
     },
 
+    #' @description
+    #' Opens the corresponding help page referenced by field `$man`.
+    help = function() {
+      open_help(self$man)
+    },
+
+    #' @description
+    #' Calculates the performance for all provided measures
+    #' [Task] and [Learner] may be `NULL` for most measures, but some measures need to extract information
+    #' from these objects.
+    #'
+    #' @param task ([Task]).
+    #'
+    #' @param learner ([Learner]).
+    #'
+    #' @param train_set (`integer()`).
+    #'
+    #' @return [Prediction].
     score = function(measures = NULL, task = NULL, learner = NULL, train_set = NULL) {
       measures = assert_measures(as_measures(measures, task_type = self$task_type), task = task, learner = learner)
       scores = map_dbl(measures, function(m) m$score(prediction = self, task = task, learner = learner, train_set = train_set))
@@ -92,9 +93,26 @@ Prediction = R6Class("Prediction",
   ),
 
   active = list(
-    row_ids = function() self$data$tab$row_id,
-    truth = function() self$data$tab$truth,
-    missing = function() self$data$tab$row_id[0L] # empty vector
+    #' @field row_ids (`integer()`)\cr
+    #'   Vector of row ids for which predictions are stored.
+    row_ids = function(rhs) {
+      assert_ro_binding(rhs)
+      self$data$tab$row_id
+    },
+
+    #' @field truth (`any`)\cr
+    #'   True (observed) outcome.
+    truth = function(rhs) {
+      assert_ro_binding(rhs)
+      self$data$tab$truth
+    },
+
+    #' @field missing (`integer()`)\cr
+    #'   Returns `row_ids` for which the predictions are missing or incomplete.
+    missing = function(rhs) {
+      assert_ro_binding(rhs)
+      self$data$tab$row_id[0L] # empty vector
+    }
   )
 )
 
