@@ -1,5 +1,17 @@
 context("Task")
 
+test_that("Feature columns can be reordered", {
+  bh = load_dataset("BostonHousing", "mlbench")
+  task = tsk("boston_housing")
+  task$col_roles$feature = setdiff(names(bh), "medv")
+
+  expect_equal(task$feature_names, setdiff(names(bh), "medv"))
+  expect_equal(names(task$data(rows = 1)), c("medv", setdiff(names(bh), "medv")))
+
+  task$col_roles$feature = shuffle(task$col_roles$feature)
+  expect_equal(names(task$data(rows = 1)), c("medv", task$col_roles$feature))
+})
+
 test_that("Task duplicates rows", {
   task = tsk("iris")
   data = task$data(c(1L, 1L))
