@@ -1,13 +1,10 @@
 context("parallelization")
 
 test_that("parallel resample", {
-  skip_if_not_installed("future")
   skip_if_not_installed("future.callr")
   skip_if_not_installed("progressr")
 
   with_future(future.callr::callr, {
-    expect_true(use_future())
-
     task = tsk("iris")
     learner = lrn("classif.rpart")
 
@@ -20,12 +17,9 @@ test_that("parallel resample", {
 })
 
 test_that("parallel benchmark", {
-  skip_if_not_installed("future")
   skip_if_not_installed("future.callr")
 
   with_future(future.callr::callr, {
-    expect_true(use_future())
-
     task = tsk("iris")
     learner = lrn("classif.rpart")
 
@@ -39,14 +33,11 @@ test_that("parallel benchmark", {
 })
 
 test_that("real parallel resample", {
-  skip_if_not_installed("future")
   skip_if_not_installed("future.callr")
   skip_if_not_installed("progressr")
   skip_on_os("windows") # currently buggy
 
   with_future(future::multiprocess, {
-    expect_true(use_future())
-
     task = tsk("iris")
     learner = lrn("classif.rpart")
 
@@ -57,3 +48,16 @@ test_that("real parallel resample", {
     expect_data_table(rr$errors, nrows = 0L)
   })
 })
+
+test_that("parallel seed", {
+  skip_if_not_installed("future.callr")
+
+  task = tsk("wine")
+  learner = lrn("classif.debug", predict_type = "prob")
+
+  rr1 = with_seed(123, resample(task, learner, rsmp("cv", folds = 3)))
+  with_future(future.callr::callr, {
+    rr2 = with_seed(123, resample(task, learner, rsmp("cv", folds = 3)))
+  })
+  expect_equal(rr1$prediction()$prob, rr2$prediction()$prob)
+})
